@@ -10,7 +10,7 @@ except ImportError:
     cwd = Path(__file__).parent.parent
     sys.path.append(cwd.as_posix())
 
-from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils, QRScanner
+from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils, QRScanner, findVTRx
 import gi
 
 gi.require_version("Gtk", "3.0")
@@ -20,27 +20,6 @@ from gi.repository import Gtk, Gio, GLib
 gtk_runs, gtk_args = Gtk.init_check()
 
 
-def find_vtrx(client, SN):
-    """Searches VTRx."""
-    payload = {
-        "filterMap": {
-            "project": "CE",
-            "componentType": ["VTRX"],
-            "propertyFilter": [{"code": "PACKAGE_SN", "operator": "=", "value": SN}],
-        }
-    }
-    out = client.get("listComponentsByProperty", json=payload)
-    vtrx = None
-    nitem = 0
-    for item in out:
-        vtrx = item["serialNumber"]
-        nitem += 1
-
-    if nitem > 1:
-        raise ValueError("Too many VTRx with same device SN.")
-
-    return vtrx
-
 class ReceiveShipments(dbGtkUtils.ITkDBWindow):
     """Find shipments related to given recipient."""
 
@@ -187,9 +166,9 @@ class ReceiveShipments(dbGtkUtils.ITkDBWindow):
         """Gets data from QR scanner."""
         self.write_message("{}\n".format(txt))
 
-        if txt.find("J-SD") == 0:
+        if findVTRx.is_vtrx(txt):
             try:
-                txt = find_vtrx(self.session, txt)
+                txt = findVTRx.find_vtrx(self.session, txt)
             except ValueError as e:
                 self.write_message("Error: {}\n".format(e))
                 return
