@@ -1,5 +1,4 @@
 """Utilities for the inteaction with the ITkDB."""
-import mimetypes
 from collections.abc import Iterable
 from datetime import datetime
 from pathlib import Path
@@ -202,7 +201,7 @@ def create_component_attachment(client, SN, file_path, title=None, description="
     global db_response
     db_response = None
     path = Path(file_path).expanduser().resolve()
-    filetype = mimetypes.guess_type(path)
+    filetype =   itkdb.utils.get_mimetype(path, None)
     if title is None:
         title = path.name
 
@@ -384,6 +383,11 @@ def upload_test(client, data, attachments=None, check_runNumber=False):
         testRun = db_response["testRun"]["id"]
         uploaded_test_runs.append(testRun)
 
+    except Exception as e:
+        msg = "Could not upload the test:\n{}".format(str(e))
+        return msg
+
+    try:
         # Handle attachments.
         attachment_urls = {}
         if attachments is not None:
@@ -403,11 +407,11 @@ def upload_test(client, data, attachments=None, check_runNumber=False):
                         continue
 
                     data["url"] = path.as_uri()
-                    filetype = mimetypes.guess_type(path.name)
-                    attachment = {'data': (path.as_posix(), open(path.as_posix(), 'rb'), filetype[0])}
+                    filetype = itkdb.utils.get_mimetype(path.as_posix(), None)
+                    attachment = {'data': (path.as_posix(), open(path.as_posix(), 'rb'), filetype)}
                 else:
                     data["url"] = att.url
-                    filetype = mimetypes.guess_type(att.url)
+                    filetype = itkdb.utils.get_mimetype(att.url, None)
                     attachment = {'data':(att.url, None, "text/x-uri") }
 
                 db_response = client.post('createTestRunAttachment',
@@ -424,7 +428,8 @@ def upload_test(client, data, attachments=None, check_runNumber=False):
         return None
 
     except Exception as e:
-        return (str(e))
+        return "Could not upload attachment:\n{}".format(str(e))
+
 
 def set_test_run_parameter(session, test_run, parameter, value):
     """Modify testRun Parameter
